## 0.0.3

This new version includes some important changes to the project structure and setup.

### New Features

- No new features were added in this version.

### Bug Fixes

- No bug fixes were made in this version.

### Deprecations

- Removed the setup.py file, indicating a change in the project setup process ([796163](https://github.com/ericmjl/llamabot/commit/796163e52912afec9b6926add5e424604689fce1))
